==> moodle_1.3.1.orig.tar.gz: moodle/lang/zh_cn/workshop.php <==
<?PHP // $Id: workshop.php,v 1.6 2004/03/10 08:28:28 moodler Exp $ 
      // workshop.php - created with Moodle 1.2 Beta (2004022400)


$string['absent'] = 'ȱϯ';
$string['accumulative'] = 'ۻ';
$string['action'] = '';
$string['addacomment'] = 'һ';
$string['afterdeadline'] = 'ޣ $a';
$string['agreetothisassessment'] = 'ͬ';
$string['allgradeshaveamaximumof'] = '÷߲ڣ $a';
$string['allowresubmit'] = 'ؽ';
$string['alreadyinphase'] = 'Ѿڽ׶ $a';
$string['amendassessmentelements'] = '޸Ҫ';
$string['amendtitle'] = 'Amend Title';
$string['analysisofassessments'] = 'Analysis of Assessments';
$string['assess'] = '';
$string['assessedon'] = ' $a ';
$string['assessment'] = '';
$string['assessmentby'] = ' $a ';
$string['assessmentdropped'] = 'Assessment Dropped';
$string['assessmentgrade'] = '۵÷֣ $a';
$string['assessmentnotyetagreed'] = 'ۻδ';
$string['assessmentofresubmission'] = 'This is an Assessment of a revised piece of the work. <br />The form here has been filled with your previous grades and comments. <br />Please amend these after looking at the revised work.';
$string['assessmentofthissubmission'] = 'ύ';
$string['assessments'] = '';
$string['assessmentsareok'] = '۲';
$string['assessmentsby'] = ' $a ';
$string['assessmentsdone'] = '';
$string['assessmentsexcluded'] = 'Number of Assessments excluded for this $a';
$string['assessmentsmustbeagreed'] = '뾭';
$string['assessmentwasagreedon'] = ' $a ';
$string['assessor'] = '';
$string['assessthissubmission'] = 'ύ';
$string['assignmentnotinthecorrectphase'] = 'ҵȷĽ׶';
$string['authorofsubmission'] = 'ύҵ';
$string['averageerror'] = 'Average Error';
$string['awaitinggradingbyteacher'] = 'ȴ $a ';
$string['beforedeadline'] = 'ޣ $a';
$string['calculationoffinalgrades'] = '÷ܼ';
$string['closeassignment'] = 'ҵ';
$string['comment'] = '';
$string['commentby'] = '';
$string['confirmdeletionofthisitem'] = 'Confirm Deletion of this $a';
$string['correct'] = 'Correct';
$string['criterion'] = 'Criterion';
$string['deadline'] = '';
$string['deadlineis'] = 'Ϊ $a';
$string['delete'] = 'ɾ';
$string['deleting'] = 'Deleting';
$string['description'] = '';
$string['detailsofassessment'] = '۵ľ';
$string['disagreewiththisassessment'] = 'ͬ';
$string['displayoffinalgrades'] = 'ʾ÷';
$string['dontshowgrades'] = 'ʾ÷';
$string['edit'] = '༭';
$string['editacomment'] = '༭һ';
$string['editingassessmentelements'] = '༭Ҫ';
$string['element'] = 'Ҫ';
$string['elementweight'] = 'ҪȨ';
$string['errorbanded'] = 'Χ';
$string['errortable'] = 'Error Table';
$string['excellent'] = '';
$string['excludingdroppedassessments'] = 'excluding dropped Assessments';
$string['expectederror'] = 'Expected Error Value if guessing: $a';
$string['feedbackgoeshere'] = '';
$string['generalcomment'] = 'һ';
$string['good'] = '';
$string['grade'] = '';
$string['gradeassessment'] = '';
$string['graded'] = '';
$string['gradedbyteacher'] = ' $a ';
$string['gradeforassessments'] = '';
$string['gradeforbias'] = 'ƫ';
$string['gradeforreliability'] = 'Կɿ';
$string['gradeforstudentsassessment'] = 'ѧ';
$string['gradeforsubmission'] = 'Grade for Submission';
$string['gradeofsubmission'] = 'ύĵ÷֣ $a';
$string['gradetable'] = 'Grade Table';
$string['gradingstrategy'] = 'ֲ';
$string['hidegradesbeforeagreement'] = '֮ǰ';
$string['hidenamesfromstudents'] = 'Hide Names from $a';
$string['includeteachersgrade'] = 'ʦ';
$string['incorrect'] = '';
$string['iteration'] = 'Iteration $a completed';
$string['leaguetable'] = 'League Table of Submitted Work';
$string['listassessments'] = 'г';
$string['listofallsubmissions'] = 'ȫύб';
$string['liststudentsassessments'] = 'List Student\'s Assessments';
$string['loadingforteacherassessments'] = 'Loading for $a Assessments';
$string['mail1'] = 'Your assignment \'$a\' has been assessed by';
$string['mail10'] = 'You can assess it in your workshop assignment ';
$string['mail2'] = 'The comments and grade can be seen in the Workshop Assignment \'$a\'';
$string['mail3'] = 'You can see it in your Workshop Assignment';
$string['mail4'] = 'A comment has been added to the assignment \'$a\' by';
$string['mail5'] = 'The new comment can be seen in the Workshop Assignment \'$a\'';
$string['mail6'] = 'Your assessment of the assignment \'$a\' has by reviewed';
$string['mail7'] = 'The comments given by the $a can be seen in the Workshop Assignment ';
$string['mail8'] = 'The assignment $a is a revised piece of work. ';
$string['mail9'] = 'Please assess it in the workshop assignment $a ';
$string['managingassignment'] = 'ҵ';
$string['maximumsize'] = 'С';
$string['modulename'] = 'ר';
$string['modulenameplural'] = 'ר';
$string['movingtophase'] = 'Moving to Phase $a';
$string['namesnotshowntostudents'] = 'Names not shown to $a';
$string['newassessments'] = 'New Assessments';
$string['newgradings'] = 'New Gradings';
$string['newsubmissions'] = 'New Submissions';
$string['noassessments'] = 'No Assessments';
$string['noassessmentsdone'] = 'ɵ';
$string['nosubmission'] = 'No Submission';
$string['nosubmissionsavailableforassessment'] = 'No Submissions available for assessment';
$string['notavailable'] = 'û';
$string['noteonassessmentelements'] = 'ע⣬÷ֿɷֽΪһЩҪء.<BR>
	ʹֱұһԡ <BR>
	Ϊʦڲúҵ֮ǰЩҪء<BR>
	γеĲҵûָҪأͻῴʾҪҪء<BR>
	ʹñ༭ҵҳıҪص<BR>
	Ҫرڡҵҳ޸ġ';
$string['notgraded'] = 'δ';
$string['notitlegiven'] = 'δ';
$string['numberofassessmentelements'] = '۵ĿҪء÷ַΧ׼';
$string['numberofassessments'] = '۵Ŀ';
$string['numberofassessmentschanged'] = 'Number of Assessments Changed: $a';
$string['numberofassessmentsofstudentsubmissions'] = 'ѧҵĿ';
$string['numberofassessmentsofteachersexamples'] = 'ԽʦĿ';
$string['numberofentries'] = 'Number of Entries';
$string['numberofnegativeresponses'] = 'Number of Negative Responses';
$string['numberofsubmissions'] = 'Number of Submissions: $a';
$string['on'] = ' $a';
$string['openassignment'] = 'ҵ';
$string['optionaladjustment'] = 'Optional Adjustment';
$string['optionforpeergrade'] = 'ͬѧѡ';
$string['optionsusedinanalysis'] = 'Options used in Analysis';
$string['overallgrade'] = 'ȫ÷';
$string['overallocation'] = 'Over Allocation';
$string['overallpeergrade'] = 'ȫͬѧ֣ $a';
$string['overallteachergrade'] = 'ȫʦ֣ $a';
$string['ownwork'] = 'Own Work';
$string['percentageofassessments'] = 'Percentage of Assessments to Drop';
$string['phase'] = '׶';
$string['phase1'] = 'ҵ';
$string['phase1short'] = 'Set Up';
$string['phase2'] = '$a ύ';
$string['phase2short'] = 'Submissions';
$string['phase3'] = '÷ܼ';
$string['phase3short'] = 'Both';
$string['phase4'] = 'ʾ÷';
$string['phase4short'] = 'Assessments';
$string['phase5'] = 'Calculation of Final Grades';
$string['phase5short'] = 'Calculation';
$string['phase6'] = 'Show Final Grades';
$string['phase6short'] = 'Show Grades';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'Щ $a ';
$string['pleaseassessthesestudentsubmissions'] = 'Щ $a ύҵ';
$string['pleaseassessyoursubmissions'] = 'Please assess your Submission(s)';
$string['poor'] = '';
$string['present'] = 'Present';
$string['reasonforadjustment'] = 'Reason for Adjustment';
$string['reassess'] = '';
$string['repeatanalysis'] = 'Repeat Analysis';
$string['reply'] = '';
$string['returnto'] = 'ص';
$string['returntosubmissionpage'] = 'صύҳ';
$string['rubric'] = 'Rubric';
$string['savedok'] = '';
$string['saveleaguetableoptions'] = 'Save League Table Options';
$string['savemyassessment'] = 'ҵ';
$string['savemycomment'] = 'ҵ';
$string['savemygrading'] = 'ҵ';
$string['saveoverallocation'] = 'Save Over Allocation Level';
$string['scale10'] = ' 10';
$string['scale100'] = ' 100';
$string['scale20'] = ' 20';
$string['scalecorrect'] = '2 ȷ/';
$string['scaleexcellent4'] = '4 㼫/';
$string['scaleexcellent5'] = '5 㼫/';
$string['scaleexcellent7'] = '7 㼫/';
$string['scalegood3'] = '3 /';
$string['scalepresent'] = '2 /';
$string['scaleyes'] = '2 /';
$string['select'] = 'ѡ';
$string['selfassessment'] = '';
$string['setoverallocation'] = 'Set Over Allocation Level';
$string['showgrades'] = 'ʾ÷';
$string['specimenassessmentform'] = '۱';
$string['standarddeviation'] = 'Standard deviation of Element $a:';
$string['standarddeviationnote'] = 'Elements with standard deviations of zero or very small values can distort the analysis.<br /> This Element has been excluded from the analysis.';
$string['studentassessments'] = '$a Assessments';
$string['studentgrades'] = '$a ';
$string['studentsubmissions'] = '$a ύ';
$string['studentsubmissionsforassessment'] = '$a ѧύ';
$string['submission'] = 'Submission';
$string['submissions'] = 'Submissions';
$string['submissionsnolongerallowed'] = 'Submissions no longer allowed';
$string['submissionsused'] = '$a Submissions used in this table';
$string['submitassignment'] = 'ύõҵ';
$string['submitassignmentusingform'] = 'øñύҵ';
$string['submitexampleassignment'] = 'ύҵ';
$string['submitrevisedassignment'] = 'øñύĺҵ';
$string['submitted'] = 'ύ';
$string['submittedby'] = 'ύ';
$string['suggestedgrade'] = '÷';
$string['teacherassessments'] = '$a Assessments';
$string['teacherscomment'] = 'ʦ';
$string['teachersgrade'] = 'ʦ';
$string['teachersubmissionsforassessment'] = '$a ʦύ';
$string['thegradeis'] = '÷Ϊ $a';
$string['thereisfeedbackfromtheteacher'] = 'There is feadback from the $a';
$string['theseasessmentsaregradedbytheteacher'] = 'Щ $a ';
$string['timeassessed'] = 'ʱ';
$string['title'] = '';
$string['typeofscale'] = '';
$string['ungradedassessmentsofstudentsubmissions'] = '$a ¶ѧύ';
$string['ungradedassessmentsofteachersubmissions'] = '$a ¶Խʦύ';
$string['verypoor'] = '';
$string['view'] = '鿴';
$string['viewassessmentofteacher'] = '鿴 $a ';
$string['viewotherassessments'] = '鿴';
$string['warningonamendingelements'] = '<b></b>Ѿύۡ <BR><b><big>Ҫ</big></b>ıҪصĿͻҪصȨء';
$string['weight'] = 'Ȩ';
$string['weightederrorcount'] = 'ȨĴ $a';
$string['weightforbias'] = 'ƫȨ';
$string['weightforgradingofassessments'] = '۵ĵ÷Ȩ';
$string['weightforpeerassessments'] = 'ͬѧ۵Ȩ';
$string['weightforreliability'] = 'ɿԵȨ';
$string['weights'] = 'Ȩ';
$string['weightsusedforfinalgrade'] = '÷ֵȨ';
$string['weightsusedforsubmissions'] = 'ύȨ';
$string['workshopagreedassessments'] = 'Workshop Agreed Assessments';
$string['workshopassessments'] = 'Workshop Assessments';
$string['workshopcomments'] = 'Workshop Comments';
$string['workshopfeedback'] = 'Workshop Feedback';
$string['workshopsubmissions'] = 'Workshop Submissions';
$string['yourassessments'] = '';
$string['yourassessmentsofexamplesfromtheteacher'] = 'Your Assessments of Examples from the $a';
$string['yourfeedbackgoeshere'] = 'ķ';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/zh_cn/workshop.php <==
<?PHP // $Id$ 
      // workshop.php - created with Moodle 1.2 Beta (2004022400)


$string['absent'] = 'ȱϯ';
$string['accumulative'] = 'ۻ';
$string['action'] = '';
$string['addacomment'] = 'һ';
$string['afterdeadline'] = 'ޣ $a';
$string['agreetothisassessment'] = 'ͬ';
$string['allgradeshaveamaximumof'] = '÷߲ڣ $a';
$string['allowresubmit'] = 'ؽ';
$string['alreadyinphase'] = 'Ѿڽ׶ $a';
$string['amendassessmentelements'] = '޸Ҫ';
$string['amendtitle'] = 'Amend Title';
$string['analysisofassessments'] = 'Analysis of Assessments';
$string['assess'] = '';
$string['assessedon'] = ' $a ';
$string['assessment'] = '';
$string['assessmentby'] = ' $a ';
$string['assessmentdropped'] = 'Assessment Dropped';
$string['assessmentgrade'] = '۵÷֣ $a';
$string['assessmentnotyetagreed'] = 'ۻδ';
$string['assessmentofresubmission'] = 'This is an Assessment of a revised piece of the work. <br />The form here has been filled with your previous grades and comments. <br />Please amend these after looking at the revised work.';
$string['assessmentofthissubmission'] = 'ύ';
$string['assessments'] = '';
$string['assessmentsareok'] = '۲';
$string['assessmentsby'] = ' $a ';
$string['assessmentsdone'] = '';
$string['assessmentsexcluded'] = 'Number of Assessments excluded for this $a';
$string['assessmentsmustbeagreed'] = '뾭';
$string['assessmentwasagreedon'] = ' $a ';
$string['assessor'] = '';
$string['assessthissubmission'] = 'ύ';
$string['assignmentnotinthecorrectphase'] = 'ҵȷĽ׶';
$string['authorofsubmission'] = 'ύҵ';
$string['averageerror'] = 'Average Error';
$string['awaitinggradingbyteacher'] = 'ȴ $a ';
$string['beforedeadline'] = 'ޣ $a';
$string['calculationoffinalgrades'] = '÷ܼ';
$string['closeassignment'] = 'ҵ';
$string['comment'] = '';
$string['commentby'] = '';
$string['confirmdeletionofthisitem'] = 'Confirm Deletion of this $a';
$string['correct'] = 'Correct';
$string['criterion'] = 'Criterion';
$string['deadline'] = '';
$string['deadlineis'] = 'Ϊ $a';
$string['delete'] = 'ɾ';
$string['deleting'] = 'Deleting';
$string['description'] = '';
$string['detailsofassessment'] = '۵ľ';
$string['disagreewiththisassessment'] = 'ͬ';
$string['displayoffinalgrades'] = 'ʾ÷';
$string['dontshowgrades'] = 'ʾ÷';
$string['edit'] = '༭';
$string['editacomment'] = '༭һ';
$string['editingassessmentelements'] = '༭Ҫ';
$string['element'] = 'Ҫ';
$string['elementweight'] = 'ҪȨ';
$string['errorbanded'] = 'Χ';
$string['errortable'] = 'Error Table';
$string['excellent'] = '';
$string['excludingdroppedassessments'] = 'excluding dropped Assessments';
$string['expectederror'] = 'Expected Error Value if guessing: $a';
$string['feedbackgoeshere'] = '';
$string['generalcomment'] = 'һ';
$string['good'] = '';
$string['grade'] = '';
$string['gradeassessment'] = '';
$string['graded'] = '';
$string['gradedbyteacher'] = ' $a ';
$string['gradeforassessments'] = '';
$string['gradeforbias'] = 'ƫ';
$string['gradeforreliability'] = 'Կɿ';
$string['gradeforstudentsassessment'] = 'ѧ';
$string['gradeforsubmission'] = 'Grade for Submission';
$string['gradeofsubmission'] = 'ύĵ÷֣ $a';
$string['gradetable'] = 'Grade Table';
$string['gradingstrategy'] = 'ֲ';
$string['hidegradesbeforeagreement'] = '֮ǰ';
$string['hidenamesfromstudents'] = 'Hide Names from $a';
$string['includeteachersgrade'] = 'ʦ';
$string['incorrect'] = '';
$string['iteration'] = 'Iteration $a completed';
$string['leaguetable'] = 'League Table of Submitted Work';
$string['listassessments'] = 'г';
$string['listofallsubmissions'] = 'ȫύб';
$string['liststudentsassessments'] = 'List Student\'s Assessments';
$string['loadingforteacherassessments'] = 'Loading for $a Assessments';
$string['mail1'] = 'Your assignment \'$a\' has been assessed by';
$string['mail10'] = 'You can assess it in your workshop assignment ';
$string['mail2'] = 'The comments and grade can be seen in the Workshop Assignment \'$a\'';
$string['mail3'] = 'You can see it in your Workshop Assignment';
$string['mail4'] = 'A comment has been added to the assignment \'$a\' by';
$string['mail5'] = 'The new comment can be seen in the Workshop Assignment \'$a\'';
$string['mail6'] = 'Your assessment of the assignment \'$a\' has by reviewed';
$string['mail7'] = 'The comments given by the $a can be seen in the Workshop Assignment ';
$string['mail8'] = 'The assignment $a is a revised piece of work. ';
$string['mail9'] = 'Please assess it in the workshop assignment $a ';
$string['managingassignment'] = 'ҵ';
$string['maximumsize'] = 'С';
$string['modulename'] = 'ר';
$string['modulenameplural'] = 'ר';
$string['movingtophase'] = 'Moving to Phase $a';
$string['namesnotshowntostudents'] = 'Names not shown to $a';
$string['newassessments'] = 'New Assessments';
$string['newgradings'] = 'New Gradings';
$string['newsubmissions'] = 'New Submissions';
$string['noassessments'] = 'No Assessments';
$string['noassessmentsdone'] = 'ɵ';
$string['nosubmission'] = 'No Submission';
$string['nosubmissionsavailableforassessment'] = 'No Submissions available for assessment';
$string['notavailable'] = 'û';
$string['noteonassessmentelements'] = 'ע⣬÷ֿɷֽΪһЩҪء.<br />
	ʹֱұһԡ <br />
	Ϊʦڲúҵ֮ǰЩҪء<br />
	γеĲҵûָҪأͻῴʾҪҪء<br />
	ʹñ༭ҵҳıҪص<br />
	Ҫرڡҵҳ޸ġ';
$string['notgraded'] = 'δ';
$string['notitlegiven'] = 'δ';
$string['numberofassessmentelements'] = '۵ĿҪء÷ַΧ׼';
$string['numberofassessments'] = '۵Ŀ';
$string['numberofassessmentschanged'] = 'Number of Assessments Changed: $a';
$string['numberofassessmentsofstudentsubmissions'] = 'ѧҵĿ';
$string['numberofassessmentsofteachersexamples'] = 'ԽʦĿ';
$string['numberofentries'] = 'Number of Entries';
$string['numberofnegativeresponses'] = 'Number of Negative Responses';
$string['numberofsubmissions'] = 'Number of Submissions: $a';
$string['on'] = ' $a';
$string['openassignment'] = 'ҵ';
$string['optionaladjustment'] = 'Optional Adjustment';
$string['optionforpeergrade'] = 'ͬѧѡ';
$string['optionsusedinanalysis'] = 'Options used in Analysis';
$string['overallgrade'] = 'ȫ÷';
$string['overallocation'] = 'Over Allocation';
$string['overallpeergrade'] = 'ȫͬѧ֣ $a';
$string['overallteachergrade'] = 'ȫʦ֣ $a';
$string['ownwork'] = 'Own Work';
$string['percentageofassessments'] = 'Percentage of Assessments to Drop';
$string['phase'] = '׶';
$string['phase1'] = 'ҵ';
$string['phase1short'] = 'Set Up';
$string['phase2'] = '$a ύ';
$string['phase2short'] = 'Submissions';
$string['phase3'] = '÷ܼ';
$string['phase3short'] = 'Both';
$string['phase4'] = 'ʾ÷';
$string['phase4short'] = 'Assessments';
$string['phase5'] = 'Calculation of Final Grades';
$string['phase5short'] = 'Calculation';
$string['phase6'] = 'Show Final Grades';
$string['phase6short'] = 'Show Grades';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'Щ $a ';
$string['pleaseassessthesestudentsubmissions'] = 'Щ $a ύҵ';
$string['pleaseassessyoursubmissions'] = 'Please assess your Submission(s)';
$string['poor'] = '';
$string['present'] = 'Present';
$string['reasonforadjustment'] = 'Reason for Adjustment';
$string['reassess'] = '';
$string['repeatanalysis'] = 'Repeat Analysis';
$string['reply'] = '';
$string['returnto'] = 'ص';
$string['returntosubmissionpage'] = 'صύҳ';
$string['rubric'] = 'Rubric';
$string['savedok'] = '';
$string['saveleaguetableoptions'] = 'Save League Table Options';
$string['savemyassessment'] = 'ҵ';
$string['savemycomment'] = 'ҵ';
$string['savemygrading'] = 'ҵ';
$string['saveoverallocation'] = 'Save Over Allocation Level';
$string['scale10'] = ' 10';
$string['scale100'] = ' 100';
$string['scale20'] = ' 20';
$string['scalecorrect'] = '2 ȷ/';
$string['scaleexcellent4'] = '4 㼫/';
$string['scaleexcellent5'] = '5 㼫/';
$string['scaleexcellent7'] = '7 㼫/';
$string['scalegood3'] = '3 /';
$string['scalepresent'] = '2 /';
$string['scaleyes'] = '2 /';
$string['select'] = 'ѡ';
$string['selfassessment'] = '';
$string['setoverallocation'] = 'Set Over Allocation Level';
$string['showgrades'] = 'ʾ÷';
$string['specimenassessmentform'] = '۱';
$string['standarddeviation'] = 'Standard deviation of Element $a:';
$string['standarddeviationnote'] = 'Elements with standard deviations of zero or very small values can distort the analysis.<br /> This Element has been excluded from the analysis.';
$string['studentassessments'] = '$a Assessments';
$string['studentgrades'] = '$a ';
$string['studentsubmissions'] = '$a ύ';
$string['studentsubmissionsforassessment'] = '$a ѧύ';
$string['submission'] = 'Submission';
$string['submissions'] = 'Submissions';
$string['submissionsnolongerallowed'] = 'Submissions no longer allowed';
$string['submissionsused'] = '$a Submissions used in this table';
$string['submitassignment'] = 'ύõҵ';
$string['submitassignmentusingform'] = 'øñύҵ';
$string['submitexampleassignment'] = 'ύҵ';
$string['submitrevisedassignment'] = 'øñύĺҵ';
$string['submitted'] = 'ύ';
$string['submittedby'] = 'ύ';
$string['suggestedgrade'] = '÷';
$string['teacherassessments'] = '$a Assessments';
$string['teacherscomment'] = 'ʦ';
$string['teachersgrade'] = 'ʦ';
$string['teachersubmissionsforassessment'] = '$a ʦύ';
$string['thegradeis'] = '÷Ϊ $a';
$string['thereisfeedbackfromtheteacher'] = 'There is feadback from the $a';
$string['theseasessmentsaregradedbytheteacher'] = 'Щ $a ';
$string['timeassessed'] = 'ʱ';
$string['title'] = '';
$string['typeofscale'] = '';
$string['ungradedassessmentsofstudentsubmissions'] = '$a ¶ѧύ';
$string['ungradedassessmentsofteachersubmissions'] = '$a ¶Խʦύ';
$string['verypoor'] = '';
$string['view'] = '鿴';
$string['viewassessmentofteacher'] = '鿴 $a ';
$string['viewotherassessments'] = '鿴';
$string['warningonamendingelements'] = '<b></b>Ѿύۡ <br /><b><big>Ҫ</big></b>ıҪصĿͻҪصȨء';
$string['weight'] = 'Ȩ';
$string['weightederrorcount'] = 'ȨĴ $a';
$string['weightforbias'] = 'ƫȨ';
$string['weightforgradingofassessments'] = '۵ĵ÷Ȩ';
$string['weightforpeerassessments'] = 'ͬѧ۵Ȩ';
$string['weightforreliability'] = 'ɿԵȨ';
$string['weights'] = 'Ȩ';
$string['weightsusedforfinalgrade'] = '÷ֵȨ';
$string['weightsusedforsubmissions'] = 'ύȨ';
$string['workshopagreedassessments'] = 'Workshop Agreed Assessments';
$string['workshopassessments'] = 'Workshop Assessments';
$string['workshopcomments'] = 'Workshop Comments';
$string['workshopfeedback'] = 'Workshop Feedback';
$string['workshopsubmissions'] = 'Workshop Submissions';
$string['yourassessments'] = '';
$string['yourassessmentsofexamplesfromtheteacher'] = 'Your Assessments of Examples from the $a';
$string['yourfeedbackgoeshere'] = 'ķ';

?>
